# psi_eligibility

PsiEligibility - the Ruby gem for the PSI Candidate Rest Eligibility Service

PSIs REST based service to modify candidate test eligibilities.

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0.0
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.RubyClientCodegen

## Installation

### Build a gem

To build the Ruby code into a gem:

```shell
gem build psi_eligibility.gemspec
```

Then either install the gem locally:

```shell
gem install ./psi_eligibility-1.0.0.gem
```
(for development, run `gem install --dev ./psi_eligibility-1.0.0.gem` to install the development dependencies)

or publish the gem to a gem hosting service, e.g. [RubyGems](https://rubygems.org/).

Finally add this to the Gemfile:

    gem 'psi_eligibility', '~> 1.0.0'

### Install from Git

If the Ruby gem is hosted at a git repository: https://github.com/YOUR_GIT_USERNAME/YOUR_GIT_REPO, then add the following in the Gemfile:

    gem 'psi_eligibility', :git => 'https://github.com/YOUR_GIT_USERNAME/YOUR_GIT_REPO.git'

### Include the Ruby code directly

Include the Ruby code directly using `-I` as follows:

```shell
ruby -Ilib script.rb
```

## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'psi_eligibility'

# Setup authorization
PsiEligibility.configure do |config|
  # Configure OAuth2 access token for authorization: oauth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = PsiEligibility::DefaultApi.new

account_code = 'account_code_example' # String | provided client specific account code.

candidate_id = 'candidate_id_example' # String | The unique candidate id to act on.

test_code = 'test_code_example' # String | The test code.


begin
  #Cancel a candidate's eligibility record.
  api_instance.cancel_candidate_eligibility(account_code, candidate_id, test_code)
rescue PsiEligibility::ApiError => e
  puts "Exception when calling DefaultApi->cancel_candidate_eligibility: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://apiuatapi.psiexams.com/eligibility_service/1.0.0*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*PsiEligibility::DefaultApi* | [**cancel_candidate_eligibility**](docs/DefaultApi.md#cancel_candidate_eligibility) | **DELETE** /accounts/{account_code}/candidates/{candidate_id}/tests/{test_code} | Cancel a candidate's eligibility record.
*PsiEligibility::DefaultApi* | [**create_candidate**](docs/DefaultApi.md#create_candidate) | **POST** /accounts/{account_code}/candidates | Create a new candidate eligibility record.
*PsiEligibility::DefaultApi* | [**get_candidate**](docs/DefaultApi.md#get_candidate) | **GET** /accounts/{account_code}/candidates/{candidate_id} | Get the eligiblities associated with the candidate id.
*PsiEligibility::DefaultApi* | [**get_candidate_eligibilities**](docs/DefaultApi.md#get_candidate_eligibilities) | **GET** /accounts/{account_code}/candidates/{candidate_id}/tests/{test_code} | Get the eligiblities associated with the candidate id.
*PsiEligibility::DefaultApi* | [**get_test_launch_info**](docs/DefaultApi.md#get_test_launch_info) | **GET** /eligibilities/{psi_eligibility_code}/testLaunchInfo | GET test launch url
*PsiEligibility::DefaultApi* | [**modify_vouchers_of_eligibility**](docs/DefaultApi.md#modify_vouchers_of_eligibility) | **PUT** /accounts/{account_code}/candidates/{candidate_id}/tests/{test_code}/vouchers | Associate a set of voucher codes to PSI Candidate Test Eligibility record. Previously attached vouchers to the eligibility record but not listed in the input would be unlinked from the eligibility record. Voucher Codes are agreed upon codes between PSI and the customer (identified by account_code)
*PsiEligibility::DefaultApi* | [**update_candidate_eligibility**](docs/DefaultApi.md#update_candidate_eligibility) | **PUT** /accounts/{account_code}/candidates/{candidate_id}/tests/{test_code} | Update an existing candidate's eligibility record.


## Documentation for Models

 - [PsiEligibility::AdditionalAttributeModel](docs/AdditionalAttributeModel.md)
 - [PsiEligibility::CandidateModel](docs/CandidateModel.md)
 - [PsiEligibility::EligibilityModel](docs/EligibilityModel.md)
 - [PsiEligibility::EligibilityResponseModel](docs/EligibilityResponseModel.md)
 - [PsiEligibility::ErrorModel](docs/ErrorModel.md)
 - [PsiEligibility::ExistingEligibilityModel](docs/ExistingEligibilityModel.md)
 - [PsiEligibility::TestLaunchInfoModel](docs/TestLaunchInfoModel.md)


## Documentation for Authorization


### default

- **Type**: OAuth
- **Flow**: implicit
- **Authorization URL**: https://apiuatapi.psiexams.com/authorize
- **Scopes**: N/A

### oauth

- **Type**: OAuth
- **Flow**: password
- **Authorization URL**: 
- **Scopes**: N/A

