# PsiEligibility::DefaultApi

All URIs are relative to *https://apiuatapi.psiexams.com/eligibility_service/1.0.0*

Method | HTTP request | Description
------------- | ------------- | -------------
[**cancel_candidate_eligibility**](DefaultApi.md#cancel_candidate_eligibility) | **DELETE** /accounts/{account_code}/candidates/{candidate_id}/tests/{test_code} | Cancel a candidate&#39;s eligibility record.
[**create_candidate**](DefaultApi.md#create_candidate) | **POST** /accounts/{account_code}/candidates | Create a new candidate eligibility record.
[**get_candidate**](DefaultApi.md#get_candidate) | **GET** /accounts/{account_code}/candidates/{candidate_id} | Get the eligiblities associated with the candidate id.
[**get_candidate_eligibilities**](DefaultApi.md#get_candidate_eligibilities) | **GET** /accounts/{account_code}/candidates/{candidate_id}/tests/{test_code} | Get the eligiblities associated with the candidate id.
[**get_test_launch_info**](DefaultApi.md#get_test_launch_info) | **GET** /eligibilities/{psi_eligibility_code}/testLaunchInfo | GET test launch url
[**modify_vouchers_of_eligibility**](DefaultApi.md#modify_vouchers_of_eligibility) | **PUT** /accounts/{account_code}/candidates/{candidate_id}/tests/{test_code}/vouchers | Associate a set of voucher codes to PSI Candidate Test Eligibility record. Previously attached vouchers to the eligibility record but not listed in the input would be unlinked from the eligibility record. Voucher Codes are agreed upon codes between PSI and the customer (identified by account_code)
[**update_candidate_eligibility**](DefaultApi.md#update_candidate_eligibility) | **PUT** /accounts/{account_code}/candidates/{candidate_id}/tests/{test_code} | Update an existing candidate&#39;s eligibility record.


# **cancel_candidate_eligibility**
> cancel_candidate_eligibility(account_code, candidate_id, test_code)

Cancel a candidate's eligibility record.

Cancels the eligibility matching the supplied candidate eligiblity code.

### Example
```ruby
# load the gem
require 'psi_eligibility'
# setup authorization
PsiEligibility.configure do |config|
  # Configure OAuth2 access token for authorization: oauth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = PsiEligibility::DefaultApi.new

account_code = 'account_code_example' # String | provided client specific account code.

candidate_id = 'candidate_id_example' # String | The unique candidate id to act on.

test_code = 'test_code_example' # String | The test code.


begin
  #Cancel a candidate's eligibility record.
  api_instance.cancel_candidate_eligibility(account_code, candidate_id, test_code)
rescue PsiEligibility::ApiError => e
  puts "Exception when calling DefaultApi->cancel_candidate_eligibility: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_code** | **String**| provided client specific account code. | 
 **candidate_id** | **String**| The unique candidate id to act on. | 
 **test_code** | **String**| The test code. | 

### Return type

nil (empty response body)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json; charset=UTF-8



# **create_candidate**
> EligibilityResponseModel create_candidate(account_code, payload)

Create a new candidate eligibility record.

Submits a single eligibilites to the PSI Atlas system. Many parameters are optional but the more the better.

### Example
```ruby
# load the gem
require 'psi_eligibility'
# setup authorization
PsiEligibility.configure do |config|
  # Configure OAuth2 access token for authorization: oauth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = PsiEligibility::DefaultApi.new

account_code = 'account_code_example' # String | provided client specific account code.

payload = PsiEligibility::EligibilityModel.new # EligibilityModel | A new eligibility record.


begin
  #Create a new candidate eligibility record.
  result = api_instance.create_candidate(account_code, payload)
  p result
rescue PsiEligibility::ApiError => e
  puts "Exception when calling DefaultApi->create_candidate: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_code** | **String**| provided client specific account code. | 
 **payload** | [**EligibilityModel**](EligibilityModel.md)| A new eligibility record. | 

### Return type

[**EligibilityResponseModel**](EligibilityResponseModel.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: application/json; charset=UTF-8
 - **Accept**: application/json; charset=UTF-8



# **get_candidate**
> Array&lt;ExistingEligibilityModel&gt; get_candidate(account_code, candidate_id)

Get the eligiblities associated with the candidate id.

Get's all of the eligibilities associated with the supplied candidate_id. This is useful to decide which specific eligibility needs to be updated or deleted.

### Example
```ruby
# load the gem
require 'psi_eligibility'
# setup authorization
PsiEligibility.configure do |config|
  # Configure OAuth2 access token for authorization: oauth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = PsiEligibility::DefaultApi.new

account_code = 'account_code_example' # String | provided client specific account code.

candidate_id = 'candidate_id_example' # String | the candidate id.


begin
  #Get the eligiblities associated with the candidate id.
  result = api_instance.get_candidate(account_code, candidate_id)
  p result
rescue PsiEligibility::ApiError => e
  puts "Exception when calling DefaultApi->get_candidate: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_code** | **String**| provided client specific account code. | 
 **candidate_id** | **String**| the candidate id. | 

### Return type

[**Array&lt;ExistingEligibilityModel&gt;**](ExistingEligibilityModel.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json; charset=UTF-8



# **get_candidate_eligibilities**
> Array&lt;ExistingEligibilityModel&gt; get_candidate_eligibilities(account_code, candidate_id, test_code)

Get the eligiblities associated with the candidate id.

Get's all of the eligibilities associated with the supplied candidate_id fpr a specific test code.

### Example
```ruby
# load the gem
require 'psi_eligibility'
# setup authorization
PsiEligibility.configure do |config|
  # Configure OAuth2 access token for authorization: oauth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = PsiEligibility::DefaultApi.new

account_code = 'account_code_example' # String | provided client specific account code.

candidate_id = 'candidate_id_example' # String | the candidate id.

test_code = 'test_code_example' # String | The test code.


begin
  #Get the eligiblities associated with the candidate id.
  result = api_instance.get_candidate_eligibilities(account_code, candidate_id, test_code)
  p result
rescue PsiEligibility::ApiError => e
  puts "Exception when calling DefaultApi->get_candidate_eligibilities: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_code** | **String**| provided client specific account code. | 
 **candidate_id** | **String**| the candidate id. | 
 **test_code** | **String**| The test code. | 

### Return type

[**Array&lt;ExistingEligibilityModel&gt;**](ExistingEligibilityModel.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json; charset=UTF-8



# **get_test_launch_info**
> TestLaunchInfoModel get_test_launch_info(psi_eligibility_code)

GET test launch url

API endpoint to retrieve the test launch URL for a given eligibility code.

### Example
```ruby
# load the gem
require 'psi_eligibility'
# setup authorization
PsiEligibility.configure do |config|
  # Configure OAuth2 access token for authorization: oauth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = PsiEligibility::DefaultApi.new

psi_eligibility_code = 'psi_eligibility_code_example' # String | 


begin
  #GET test launch url
  result = api_instance.get_test_launch_info(psi_eligibility_code)
  p result
rescue PsiEligibility::ApiError => e
  puts "Exception when calling DefaultApi->get_test_launch_info: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **psi_eligibility_code** | **String**|  | 

### Return type

[**TestLaunchInfoModel**](TestLaunchInfoModel.md)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **modify_vouchers_of_eligibility**
> modify_vouchers_of_eligibility(account_code, candidate_id, test_code, opts)

Associate a set of voucher codes to PSI Candidate Test Eligibility record. Previously attached vouchers to the eligibility record but not listed in the input would be unlinked from the eligibility record. Voucher Codes are agreed upon codes between PSI and the customer (identified by account_code)

### Example
```ruby
# load the gem
require 'psi_eligibility'
# setup authorization
PsiEligibility.configure do |config|
  # Configure OAuth2 access token for authorization: oauth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = PsiEligibility::DefaultApi.new

account_code = 'account_code_example' # String | Account code or the customer code

candidate_id = 'candidate_id_example' # String | Candidate Id

test_code = 'test_code_example' # String | Test Code

opts = { 
  payload: [PsiEligibility::Array<String>.new] # Array<String> | Voucher Codes to be applied to the candidate's specified exam record
}

begin
  #Associate a set of voucher codes to PSI Candidate Test Eligibility record. Previously attached vouchers to the eligibility record but not listed in the input would be unlinked from the eligibility record. Voucher Codes are agreed upon codes between PSI and the customer (identified by account_code)
  api_instance.modify_vouchers_of_eligibility(account_code, candidate_id, test_code, opts)
rescue PsiEligibility::ApiError => e
  puts "Exception when calling DefaultApi->modify_vouchers_of_eligibility: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_code** | **String**| Account code or the customer code | 
 **candidate_id** | **String**| Candidate Id | 
 **test_code** | **String**| Test Code | 
 **payload** | **Array&lt;String&gt;**| Voucher Codes to be applied to the candidate&#39;s specified exam record | [optional] 

### Return type

nil (empty response body)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **update_candidate_eligibility**
> update_candidate_eligibility(account_code, candidate_id, test_code, payload)

Update an existing candidate's eligibility record.

Update an existing candidate's eligibility details. Information such as candidate demographic data and eligibility, expiration and scheduled start date may be changed. You cannot change the associated test via this call. To do so you must cancel and create a new eligibility.

### Example
```ruby
# load the gem
require 'psi_eligibility'
# setup authorization
PsiEligibility.configure do |config|
  # Configure OAuth2 access token for authorization: oauth
  config.access_token = 'YOUR ACCESS TOKEN'
end

api_instance = PsiEligibility::DefaultApi.new

account_code = 'account_code_example' # String | provided client specific account code.

candidate_id = 'candidate_id_example' # String | The unique candidate id to update.

test_code = 'test_code_example' # String | The test code.

payload = PsiEligibility::EligibilityModel.new # EligibilityModel | The candidate's updated eligibity record.


begin
  #Update an existing candidate's eligibility record.
  api_instance.update_candidate_eligibility(account_code, candidate_id, test_code, payload)
rescue PsiEligibility::ApiError => e
  puts "Exception when calling DefaultApi->update_candidate_eligibility: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **account_code** | **String**| provided client specific account code. | 
 **candidate_id** | **String**| The unique candidate id to update. | 
 **test_code** | **String**| The test code. | 
 **payload** | [**EligibilityModel**](EligibilityModel.md)| The candidate&#39;s updated eligibity record. | 

### Return type

nil (empty response body)

### Authorization

[oauth](../README.md#oauth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json; charset=UTF-8



